@@ -14,11 +14,13 @@ from litestar.datastructures.multi_dicts import (
     MultiMixin,
 )
 from litestar.datastructures.response_header import ResponseHeader
+from litestar.datastructures.secret_values import SecretBytes, SecretString
 from litestar.datastructures.state import ImmutableState, State
 from litestar.datastructures.upload_file import UploadFile
 from litestar.datastructures.url import URL, Address
 
 __all__ = (
+    "URL",
     "Accept",
     "Address",
     "CacheControlHeader",
@@ -33,7 +35,8 @@ __all__ = (
     "MultiMixin",
     "MutableScopeHeaders",
     "ResponseHeader",
+    "SecretBytes",
+    "SecretString",
     "State",
     "UploadFile",
-    "URL",
 )
