@@ -1,4 +1,4 @@
 from litestar.middleware.compression.facade import CompressionFacade
 from litestar.middleware.compression.middleware import CompressionMiddleware
 
-__all__ = ("CompressionMiddleware", "CompressionFacade")
+__all__ = ("CompressionFacade", "CompressionMiddleware")
