@@ -1,7 +1,7 @@
 from .base import Response
 from .file import File
 from .redirect import Redirect
-from .sse import ServerSentEvent
+from .sse import ServerSentEvent, ServerSentEventMessage
 from .streaming import Stream
 from .template import Template
 
@@ -10,6 +10,7 @@ __all__ = (
     "Redirect",
     "Response",
     "ServerSentEvent",
+    "ServerSentEventMessage",
     "Stream",
     "Template",
 )
