@@ -28,8 +28,16 @@ class JWTAuthenticationMiddleware(AbstractAuthenticationMiddleware):
     __slots__ = (
         "algorithm",
         "auth_header",
+        "require_claims",
         "retrieve_user_handler",
+        "revoked_token_handler",
+        "strict_audience",
+        "token_audience",
+        "token_cls",
+        "token_issuer",
         "token_secret",
+        "verify_expiry",
+        "verify_not_before",
     )
 
     def __init__(
@@ -43,6 +51,14 @@ class JWTAuthenticationMiddleware(AbstractAuthenticationMiddleware):
         retrieve_user_handler: Callable[[Token, ASGIConnection[Any, Any, Any, Any]], Awaitable[Any]],
         scopes: Scopes,
         token_secret: str,
+        token_cls: type[Token] = Token,
+        token_audience: Sequence[str] | None = None,
+        token_issuer: Sequence[str] | None = None,
+        require_claims: Sequence[str] | None = None,
+        verify_expiry: bool = True,
+        verify_not_before: bool = True,
+        strict_audience: bool = False,
+        revoked_token_handler: Callable[[Token, ASGIConnection[Any, Any, Any, Any]], Awaitable[Any]] | None = None,
     ) -> None:
         """Check incoming requests for an encoded token in the auth header specified, and if present retrieve the user
         from persistence using the provided function.
@@ -57,8 +73,23 @@ class JWTAuthenticationMiddleware(AbstractAuthenticationMiddleware):
             retrieve_user_handler: A function that receives a :class:`Token <.security.jwt.Token>` and returns a user,
                 which can be any arbitrary value.
             scopes: ASGI scopes processed by the authentication middleware.
-            token_secret: Secret for decoding the JWT token. This value should be equivalent to the secret used to
+            token_secret: Secret for decoding the JWT. This value should be equivalent to the secret used to
                 encode it.
+            token_cls: Token class used when encoding / decoding JWTs
+            token_audience: Verify the audience when decoding the token. If the audience
+                in the token does not match any audience given, raise a
+                :exc:`NotAuthorizedException`
+            token_issuer: Verify the issuer when decoding the token. If the issuer in
+                the token does not match any issuer given, raise a
+                :exc:`NotAuthorizedException`
+            require_claims: Require these claims to be present in the JWT payload
+            verify_expiry: Verify that the value of the ``exp`` (*expiration*) claim is in the future
+            verify_not_before: Verify that the value of the ``nbf`` (*not before*) claim is in the past
+            strict_audience: Verify that the value of the ``aud`` (*audience*) claim is a single value, and
+                not a list of values, and matches ``audience`` exactly. Requires that
+                ``accepted_audiences`` is a sequence of length 1
+            revoked_token_handler: A function that receives a :class:`Token <.security.jwt.Token>` and returns a boolean
+                indicating whether the token has been revoked.
         """
         super().__init__(
             app=app,
@@ -70,7 +101,15 @@ class JWTAuthenticationMiddleware(AbstractAuthenticationMiddleware):
         self.algorithm = algorithm
         self.auth_header = auth_header
         self.retrieve_user_handler = retrieve_user_handler
+        self.revoked_token_handler = revoked_token_handler
         self.token_secret = token_secret
+        self.token_cls = token_cls
+        self.token_audience = token_audience
+        self.token_issuer = token_issuer
+        self.require_claims = require_claims
+        self.verify_expiry = verify_expiry
+        self.verify_not_before = verify_not_before
+        self.strict_audience = strict_audience
 
     async def authenticate_request(self, connection: ASGIConnection[Any, Any, Any, Any]) -> AuthenticationResult:
         """Given an HTTP Connection, parse the JWT api key stored in the header and retrieve the user correlating to the
@@ -106,15 +145,25 @@ class JWTAuthenticationMiddleware(AbstractAuthenticationMiddleware):
         Returns:
             AuthenticationResult
         """
-        token = Token.decode(
+        token = self.token_cls.decode(
             encoded_token=encoded_token,
             secret=self.token_secret,
             algorithm=self.algorithm,
+            audience=self.token_audience,
+            issuer=self.token_issuer,
+            require_claims=self.require_claims,
+            verify_exp=self.verify_expiry,
+            verify_nbf=self.verify_not_before,
+            strict_audience=self.strict_audience,
         )
 
         user = await self.retrieve_user_handler(token, connection)
+        token_revoked = False
 
-        if not user:
+        if self.revoked_token_handler:
+            token_revoked = await self.revoked_token_handler(token, connection)
+
+        if not user or token_revoked:
             raise NotAuthorizedException()
 
         return AuthenticationResult(user=user, auth=token)
@@ -137,6 +186,14 @@ class JWTCookieAuthenticationMiddleware(JWTAuthenticationMiddleware):
         retrieve_user_handler: Callable[[Token, ASGIConnection[Any, Any, Any, Any]], Awaitable[Any]],
         scopes: Scopes,
         token_secret: str,
+        token_cls: type[Token] = Token,
+        token_audience: Sequence[str] | None = None,
+        token_issuer: Sequence[str] | None = None,
+        require_claims: Sequence[str] | None = None,
+        verify_expiry: bool = True,
+        verify_not_before: bool = True,
+        strict_audience: bool = False,
+        revoked_token_handler: Callable[[Token, ASGIConnection[Any, Any, Any, Any]], Awaitable[Any]] | None = None,
     ) -> None:
         """Check incoming requests for an encoded token in the auth header or cookie name specified, and if present
         retrieves the user from persistence using the provided function.
@@ -152,8 +209,23 @@ class JWTCookieAuthenticationMiddleware(JWTAuthenticationMiddleware):
             retrieve_user_handler: A function that receives a :class:`Token <.security.jwt.Token>` and returns a user,
                 which can be any arbitrary value.
             scopes: ASGI scopes processed by the authentication middleware.
-            token_secret: Secret for decoding the JWT token. This value should be equivalent to the secret used to
+            token_secret: Secret for decoding the JWT. This value should be equivalent to the secret used to
                 encode it.
+            token_cls: Token class used when encoding / decoding JWTs
+            token_audience: Verify the audience when decoding the token. If the audience
+                in the token does not match any audience given, raise a
+                :exc:`NotAuthorizedException`
+            token_issuer: Verify the issuer when decoding the token. If the issuer in
+                the token does not match any issuer given, raise a
+                :exc:`NotAuthorizedException`
+            require_claims: Require these claims to be present in the JWT payload
+            verify_expiry: Verify that the value of the ``exp`` (*expiration*) claim is in the future
+            verify_not_before: Verify that the value of the ``nbf`` (*not before*) claim is in the past
+            strict_audience: Verify that the value of the ``aud`` (*audience*) claim is a single value, and
+                not a list of values, and matches ``audience`` exactly. Requires that
+                ``accepted_audiences`` is a sequence of length 1
+            revoked_token_handler: A function that receives a :class:`Token <.security.jwt.Token>` and returns a boolean
+                indicating whether the token has been revoked.
         """
         super().__init__(
             algorithm=algorithm,
@@ -163,8 +235,16 @@ class JWTCookieAuthenticationMiddleware(JWTAuthenticationMiddleware):
             exclude_http_methods=exclude_http_methods,
             exclude_opt_key=exclude_opt_key,
             retrieve_user_handler=retrieve_user_handler,
+            revoked_token_handler=revoked_token_handler,
             scopes=scopes,
             token_secret=token_secret,
+            token_cls=token_cls,
+            token_audience=token_audience,
+            token_issuer=token_issuer,
+            require_claims=require_claims,
+            verify_expiry=verify_expiry,
+            verify_not_before=verify_not_before,
+            strict_audience=strict_audience,
         )
         self.auth_cookie_key = auth_cookie_key
 
