@@ -1,3 +1,6 @@
+import io
+from io import BytesIO
+
 from docs.examples.request_data.custom_request import app as custom_request_class_app
 from docs.examples.request_data.msgpack_request import app as msgpack_app
 from docs.examples.request_data.request_data_1 import app
@@ -34,6 +37,8 @@ def test_request_data_3() -> None:
         response = client.post("/", json={"id": 1, "name": "John"})
         assert response.status_code == 201
         assert response.json() == {"id": 1, "name": "John"}
+        schema = client.get("/schema/openapi.json")
+        assert "Create a new user." in schema.json()["components"]["schemas"]["User"]["description"]
 
 
 def test_request_data_4() -> None:
@@ -47,28 +52,30 @@ def test_request_data_5() -> None:
     with TestClient(app=app_5) as client:
         response = client.post(
             "/",
-            content=b'--d26a9a4ed2f441fba9ab42d04b42099e\r\nContent-Disposition: form-data; name="id"\r\n\r\n1\r\n--d26a9a4ed2f441fba9ab42d04b42099e\r\nContent-Disposition: form-data; name="name"\r\n\r\nJohn\r\n--d26a9a4ed2f441fba9ab42d04b42099e--\r\n',
-            headers={
-                "Content-Length": "211",
-                "Content-Type": "multipart/form-data; boundary=d26a9a4ed2f441fba9ab42d04b42099e",
-            },
+            files={"form_input_name": ("filename", BytesIO(b"file content"))},
+            data={"id": 1, "name": "John"},
         )
-        assert response.json() == {"id": 1, "name": "John"}
         assert response.status_code == 201
+        assert response.json() == {
+            "id": 1,
+            "name": "John",
+            "filename": "filename",
+            "size": len(b"file content"),
+        }
 
 
 def test_request_data_6() -> None:
     with TestClient(app=app_6) as client:
         response = client.post("/", files={"upload": ("hello", b"world")})
         assert response.status_code == 201
-        assert response.text == "hello, world"
+        assert response.text == f"hello,length: {len(b'world')}"
 
 
 def test_request_data_7() -> None:
     with TestClient(app=app_7) as client:
         response = client.post("/", files={"upload": ("hello", b"world")})
         assert response.status_code == 201
-        assert response.text == "hello, world"
+        assert response.text == f"hello,length: {len(b'world')}"
 
 
 def test_request_data_8() -> None:
@@ -82,16 +89,52 @@ def test_request_data_8() -> None:
 
 def test_request_data_9() -> None:
     with TestClient(app=app_9) as client:
-        response = client.post("/", files={"hello": b"there", "i'm": "steve"})
+        response = client.post("/", files={"hello": ("filename", b"there"), "i'm": ("another_filename", "steve")})
         assert response.status_code == 201
-        assert response.json() == {"hello": "there", "i'm": "steve"}
+        assert response.json() == {
+            "filename": len(b"there"),
+            "another_filename": len(b"steve"),
+        }
 
 
 def test_request_data_10() -> None:
     with TestClient(app=app_10) as client:
-        response = client.post("/", files={"foo": ("foo.txt", b"hello"), "bar": ("bar.txt", b"world")})
+        # if you pass a dict to the `files` parameter without specifying a filename, it will default to `upload
+        # so in this app it will be return the last one only...
+        #     # file (or bytes)
+        response = client.post(
+            "/",
+            files={
+                "will default to upload": io.BytesIO(b"hello world"),
+                "will default to upload also": io.BytesIO(b"another"),
+            },
+        )
         assert response.status_code == 201
-        assert response.json() == {"foo.txt": "hello", "bar.txt": "world"}
+        assert response.json().get("upload")[0] != len(b"hello world")
+        assert response.json().get("upload")[0] == len(b"another")
+
+        # if you pass the filename explicitly, it will be used as the filename
+        #     # (filename, file (or bytes))
+        response = client.post("/", files={"file": ("hello.txt", io.BytesIO(b"hello"))})
+        assert response.status_code == 201
+        assert response.json().get("hello.txt")[0] == len(b"hello")
+
+        # if you add the content type, it will be used as the content type
+        #     # (filename, file (or bytes), content_type)
+        response = client.post("/", files={"file": ("hello.txt", io.BytesIO(b"hello"), "application/x-bittorrent")})
+        assert response.status_code == 201
+        assert response.json().get("hello.txt")[0] == len(b"hello")
+        assert response.json().get("hello.txt")[1] == "application/x-bittorrent"
+
+        # finally you can specify headers like so
+        #     # (filename, file (or bytes), content_type, headers)
+        response = client.post(
+            "/", files={"file": ("hello.txt", io.BytesIO(b"hello"), "application/x-bittorrent", {"X-Foo": "bar"})}
+        )
+        assert response.status_code == 201
+        assert response.json().get("hello.txt")[0] == len(b"hello")
+        assert response.json().get("hello.txt")[1] == "application/x-bittorrent"
+        assert ("X-Foo", "bar") in response.json().get("hello.txt")[2].items()
 
 
 def test_msgpack_app() -> None:
