@@ -124,6 +124,20 @@ def test_request_asset_url(tmp_path: Path) -> None:
         assert response.status_code == 500
 
 
+def test_request_url_for_by_name() -> None:
+    @get(path="/proxy")
+    def proxy() -> None:
+        pass
+
+    @get(path="/test")
+    def root(request: Request[Any, Any, State]) -> Dict[str, str]:  # noqa: UP006
+        return {"url": request.url_for(proxy)}
+
+    with create_test_client(route_handlers=[proxy, root]) as client:
+        response = client.get("/test")
+        assert response.json() == {"url": "http://testserver.local/proxy"}
+
+
 def test_route_handler_property() -> None:
     value: Any = {}
 
