@@ -4,7 +4,7 @@ import pytest
 
 from litestar import get
 from litestar.config.cors import CORSConfig
-from litestar.middleware.cors import CORSMiddleware
+from litestar.middleware._internal.cors import CORSMiddleware
 from litestar.status_codes import HTTP_200_OK, HTTP_404_NOT_FOUND
 from litestar.testing import create_test_client
 from litestar.types.asgi_types import Method
@@ -28,7 +28,7 @@ def test_setting_cors_middleware() -> None:
             cur = cast("Any", cur.app)
         unpacked_middleware.append(cur)
         assert len(unpacked_middleware) == 4
-        cors_middleware = cast("Any", unpacked_middleware[1])
+        cors_middleware = cast("Any", unpacked_middleware[0])
         assert isinstance(cors_middleware, CORSMiddleware)
         assert cors_middleware.config.allow_headers == ["*"]
         assert cors_middleware.config.allow_methods == ["*"]
